SystemOrganization addCategory: #'AmbientTalkST-Tests'!

OstTestCase subclass: #ATTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Tests'!

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 4/1/2012 10:28'!
execDomain
	^  OstDomain currentDomain! !

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 1/23/2013 12:38'!
expectedFailures
	(Smalltalk hasClassNamed: #OstDomain) ifTrue: [
		"specific to the ad hoc implementation:"
		^ #(testNewWithInitializerATST) ].
	
	"specific to the Omni-based implementation"
	^ #(testActorAndDomain 
	    testActorAndDomainIndirect
	    testEvaluateAsyncOmnifiedIndirect
	    testEvaluateAsyncOmnified
	    testNewWithInitializerOmni)! !

!ATTests methodsFor: 'testing' stamp: 'StefanMarr 4/1/2012 10:28'!
onBaselevel
	^ OstMirror executesOnBaseLevel! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 11:24'!
testActorAndDomain
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ OstDomain currentDomain. 	].
	
	self assert: actor equals: p read.
	
	actor terminate! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 11:24'!
testActorAndDomainIndirect
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ self execDomain ].
	
	self assert: actor equals: p read.
	
	actor terminate! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 11:24'!
testEvaluateAsyncOmnified
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	
	 "This one is only for OmniST. The implementation is not stable
	  when run the first time, since we then still have the DNUs
	  on the stack that #executesOnBaseLevel does not handle."
	actor evaluateAsync: [ OstMirror executesOnBaseLevel. ].
	
	p := actor evaluateAsync: [ OstMirror executesOnBaseLevel. ].
	
	self assert: p read.
	
	actor terminate! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 11:25'!
testEvaluateAsyncOmnifiedIndirect
	"Make sure that the actor is correctly associated with its domain"
	
	| actor p |
	actor := ATActor new.
	p := actor evaluateAsync: [ self onBaselevel ].
	
	self assert: p read.
	
	actor terminate! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/23/2013 11:25'!
testNewWithInitializer
	"For the real AmbientTalk feeling"
	| result |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld).! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 1/22/2013 17:56'!
testNewWithInitializerATST
	"For the real AmbientTalk feeling"
	| result |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld).
	self assert: result isATFarRef! !

!ATTests methodsFor: 'tests' stamp: 'StefanMarr 3/22/2012 14:49'!
testNewWithInitializerOmni
	"For the real AmbientTalk feeling"
	| result domain |
	result := ATActor newWithInitializer: [ATHelloWorld new].
	
	self assert: (result isKindOf: ATHelloWorld) description: 'Result should be the blocks return value'.
	
	domain := OstMirror domainOf: result.
	self assert: domain notNil description: 'The domain of the ATHelloWorld object should have been properly initialized...'.
	self assert: (domain isKindOf: ATActor) description: '... to the ATActor object.'. ! !

OstObject subclass: #ATHelloWorld
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Tests'!

!ATHelloWorld classSide methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/7/2012 23:30'!
example
	| hello |
	hello := ATHelloWorld new.
	hello sayHello.
	hello saySomething: 'baz'.
	
	hello := ATActor newWith: [ ATHelloWorld new ].
	hello sayHello.
	hello saySomething: 'bar'.
! !

!ATHelloWorld methodsFor: 'as yet unclassified' stamp: 'StefanMarr 3/22/2012 14:39'!
sayHello
	Transcript log: 'Hello World from within an actor. Actor Domain:',
						(OstMirror domainOf: self) printString, '(', (OstMirror domainOf: self) hash asString, ')'.
	self saySomething: 'foooo'.! !

!ATHelloWorld methodsFor: 'as yet unclassified' stamp: 'StefanMarr 3/22/2012 14:43'!
saySomething: aString
	Transcript log: 'Something: ', aString, '. Actor Domain:', 
						(OstMirror domainOf: self) printString, '(', (OstMirror domainOf: self) hash asString, ')'.! !

ATActor subclass: #ATTracingActor
	instanceVariableNames: 'cnt msgTrace'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AmbientTalkST-Tests'!

!ATTracingActor methodsFor: 'initialization' stamp: 'StefanMarr 1/4/2012 14:56'!
initialize
	cnt := 0.
	msgTrace := OrderedCollection new.
	
	super initialize.! !

!ATTracingActor methodsFor: 'tracing' stamp: 'StefanMarr 1/3/2012 23:54'!
numberOfProcessedMessages
	^ cnt! !

!ATTracingActor methodsFor: 'actor semantics' stamp: 'StefanMarr 7/19/2012 22:47'!
processIncomingMessages
	| msg result |
	<omniUnenforced>
	msg := mailbox next.
	
	result := msg send.
	
	msgTrace addLast: msg selector.
	cnt := cnt + 1.
	
	msg result: result.
	! !
